@@ -8,6 +8,7 @@ use MediaWiki\Extension\Math\InputCheck\RestbaseChecker;
  * @license GPL-2.0-or-later
  */
 class MathInputCheckRestbaseTest extends MediaWikiTestCase {
+	/** @var bool */
 	protected static $hasRestbase;
 	/** @var RestbaseChecker */
 	protected $BadObject;
@@ -24,6 +25,7 @@ class MathInputCheckRestbaseTest extends MediaWikiTestCase {
 	 * This method is called before a test is executed.
 	 */
 	protected function setUp() : void {
+		$this->markTestSkipped( 'All HTTP requests are banned in tests. See T265628.' );
 		parent::setUp();
 		if ( !self::$hasRestbase ) {
 			$this->markTestSkipped( "Can not connect to Restbase Math interface." );
